==> ejc-proequipmentp-impl-3.0.0-20220426.103701-82-sources.jar: com/ejianc/business/purchase/controller/PurchaseContractRelieveSignatureController.java <==
package com.ejianc.business.purchase.controller;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.purchase.service.IPurchaseContractRelieveService;
import com.ejianc.business.purchase.service.IPurchaseContractService;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.io.Serializable;

/**
 * @author baipengyan
 */
@RestController
@RequestMapping(value = "purchaseContractRelieveSignature")
public class PurchaseContractRelieveSignatureController implements Serializable {
    private static final long serialVersionUID = 1L;

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    IPurchaseContractRelieveService service;

    @Autowired
    IPurchaseContractService contractService;

    @RequestMapping(value = "/changeStatus", method = RequestMethod.POST)
    public CommonResponse<String> changeStatus(@RequestBody String objectStr) {
        if (StringUtils.isEmpty(objectStr)) {
            throw new BusinessException("签章流程返回对象为空，请检查！");
        }
        logger.info("签章流程返回对象--{}", objectStr);
        JSONObject object = (JSONObject) JSONObject.parse(objectStr);
        String billId = object.getString("billId");
        String status = object.getString("status");
        String refCode = object.getString("refCode");
        if (StringUtils.isEmpty(billId) || StringUtils.isEmpty(status) || StringUtils.isEmpty(refCode)) {
            return CommonResponse.error("参数异常，请检查相关参数！");
        }
        return service.relieveContract(billId, status, refCode);
    }


}

==> ejc-proequipmentp-impl-3.0.0-20220516.082955-107-sources.jar: com/ejianc/business/purchase/controller/PurchaseContractRelieveSignatureController.java <==
package com.ejianc.business.purchase.controller;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.purchase.service.IPurchaseContractRelieveService;
import com.ejianc.business.purchase.service.IPurchaseContractService;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.io.Serializable;

/**
 * @author baipengyan
 */
@RestController
@RequestMapping(value = "purchaseContractRelieveSignature")
public class PurchaseContractRelieveSignatureController implements Serializable {
    private static final long serialVersionUID = 1L;

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    IPurchaseContractRelieveService service;

    @Autowired
    IPurchaseContractService contractService;

    @RequestMapping(value = "/changeStatus", method = RequestMethod.POST)
    public CommonResponse<String> changeStatus(@RequestBody String objectStr) {
        if (StringUtils.isEmpty(objectStr)) {
            throw new BusinessException("签章流程返回对象为空，请检查！");
        }
        logger.info("签章流程返回对象--{}", objectStr);
        JSONObject object = (JSONObject) JSONObject.parse(objectStr);
        String billId = object.getString("billId");
        String status = object.getString("status");
        String refCode = object.getString("refCode");
        logger.info("billId-----"+billId);
        logger.info("status-----"+status);
        logger.info("refCode-----"+refCode);
        if (StringUtils.isEmpty(billId) || StringUtils.isEmpty(status) || StringUtils.isEmpty(refCode)) {
            return CommonResponse.error("参数异常，请检查相关参数！");
        }
        return service.relieveContract(billId, status, refCode);
    }


}
